@@ -4,19 +4,19 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'arm-linux-gnueabihf-gcc-ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': 'python3.4 ../Parser/asdl_c.py',
+ 'ASDLGEN': 'python3.5 ../Parser/asdl_c.py',
  'ASDLGEN_FILES': '../Parser/asdl.py ../Parser/asdl_c.py',
  'AST_ASDL': '../Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-Wno-unused-result',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.4',
- 'BLDLIBRARY': '-lpython3.4m',
+ 'BINLIBDEST': '/usr/lib/python3.5',
+ 'BLDLIBRARY': '-lpython3.5m',
  'BLDSHARED': 'arm-linux-gnueabihf-gcc -pthread -shared -Wl,-O1 '
               '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions -Wl,-z,relro',
  'BUILDEXE': '',
@@ -25,41 +25,41 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BYTESTR_DEPS': '\\',
  'CC': 'arm-linux-gnueabihf-gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O2 -Wall '
-           '-Wstrict-prototypes -g -fstack-protector '
-           '--param=ssp-buffer-size=4 -Wformat -Werror=format-security  -g '
-           '-flto -fuse-linker-plugin',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
+           '-Wstrict-prototypes -g -fstack-protector-strong -Wformat '
+           '-Werror=format-security  -g -flto -fuse-linker-plugin '
+           '-ffat-lto-objects',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-g -fstack-protector --param=ssp-buffer-size=4 '
-                     '-Wformat -Werror=format-security',
+ 'CONFIGURE_CFLAGS': '-g -fstack-protector-strong -Wformat '
+                     '-Werror=format-security',
  'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
+ 'CONFIGURE_CPPFLAGS': '-Wdate-time -D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions -Wl,-z,relro',
  'CONFIG_ARGS': "'--enable-shared' '--prefix=/usr' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' "
-                "'--with-system-libmpdec' '--with-system-ffi' "
-                "'--with-fpectl' 'CC=arm-linux-gnueabihf-gcc' 'CFLAGS=-g "
-                '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                "-Werror=format-security ' 'LDFLAGS=-Wl,-Bsymbolic-functions "
-                "-Wl,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+                "'--with-system-libmpdec' '--with-system-ffi' '--with-fpectl' "
+                "'CC=arm-linux-gnueabihf-gcc' 'CFLAGS=-g "
+                "-fstack-protector-strong -Wformat -Werror=format-security ' "
+                "'LDFLAGS=-Wl,-Bsymbolic-functions -Wl,-z,relro' "
+                "'CPPFLAGS=-Wdate-time -D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.4m',
+ 'CONFINCLUDEPY': '/usr/include/python3.5m',
  'COREPYTHONPATH': ':plat-arm-linux-gnueabihf',
- 'COVERAGE_INFO': '/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.5-AsTze5/python3.5-3.5.2/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.5-AsTze5/python3.5-3.5.2/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -IInclude -I../Include -D_FORTIFY_SOURCE=2',
+ 'CPPFLAGS': '-I. -IInclude -I../Include -Wdate-time -D_FORTIFY_SOURCE=2',
  'CXX': 'arm-linux-gnueabihf-g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.4 /usr/lib/python3.4/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.4',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.5 /usr/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.4/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -77,9 +77,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '@EXTRAPLATDIR@',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-34m.so',
+ 'EXT_SUFFIX': '.cpython-35m-arm-linux-gnueabihf.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -109,6 +108,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 0,
  'HAVE_CHOWN': 1,
@@ -134,6 +134,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
  'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
@@ -178,6 +179,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_FUTIMESAT': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GCC_UINT128_T': 0,
@@ -202,6 +204,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 1,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
@@ -245,8 +249,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
+ 'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
@@ -303,6 +309,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
@@ -310,6 +317,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
+ 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -362,6 +370,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 1,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
@@ -375,7 +384,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRUCT_STAT_ST_GEN': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYMLINKAT': 1,
  'HAVE_SYNC': 1,
@@ -459,37 +467,37 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGTAG': '',
  'HGVERSION': '',
  'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.4m '
-                   '/usr/include/python3.4m',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.5m '
+                   '/usr/include/python3.5m',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.4m',
+ 'INCLUDEPY': '/usr/include/python3.5m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.4m.so.1.0',
+ 'INSTSONAME': 'libpython3.5m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'arm-linux-gnueabihf-g++ -pthread -shared -Wl,-O1 '
                 '-Wl,-Bsymbolic-functions',
  'LDFLAGS': '-Wl,-Bsymbolic-functions -Wl,-z,relro',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.4m.so',
+ 'LDLIBRARY': 'libpython3.5m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'arm-linux-gnueabihf-gcc -pthread -shared -Wl,-O1 '
              '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions -Wl,-z,relro',
- 'LDVERSION': '3.4m',
+ 'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.4',
+ 'LIBDEST': '/usr/lib/python3.5',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/arm-linux-gnueabihf/pkgconfig',
- 'LIBPL': '/usr/lib/python3.4/config-3.4m-arm-linux-gnueabihf',
- 'LIBRARY': 'libpython3.4m.a',
+ 'LIBPL': '/usr/lib/python3.5/config-3.5m-arm-linux-gnueabihf',
+ 'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lpthread -ldl  -lutil',
@@ -497,14 +505,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LINKCC': 'arm-linux-gnueabihf-gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions',
  'LIPO_32BIT_FLAGS': '',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
- 'LOCALMODLIBS': '-lrt   -lexpat                   -L/usr/lib -lz  -lexpat',
+ 'LOCALMODLIBS': '-lexpat                   -L/usr/lib -lz  -lexpat',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'linux',
  'MACHDEPPATH': ':plat-arm-linux-gnueabihf',
- 'MACHDEPS': 'plat-arm-linux-gnueabihf @EXTRAPLATDIR@',
+ 'MACHDEPS': 'plat-arm-linux-gnueabihf',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.4',
+ 'MACHDESTLIB': '/usr/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'arm-linux-gnueabihf-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -512,15 +523,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAKESETUP': '../Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/bin/mkdir -p',
- 'MODLIBS': '-lrt   -lexpat                   -L/usr/lib -lz  -lexpat',
+ 'MODLIBS': '-lexpat                   -L/usr/lib -lz  -lexpat',
  'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
             'Modules/arraymodule.o  Modules/mathmodule.o Modules/_math.o  '
-            'Modules/_struct.o  Modules/timemodule.o  '
-            'Modules/_randommodule.o  Modules/_elementtree.o  '
-            'Modules/_pickle.o  Modules/_datetimemodule.o  '
-            'Modules/_bisectmodule.o  Modules/_heapqmodule.o  '
-            'Modules/unicodedata.o  Modules/fcntlmodule.o  '
-            'Modules/spwdmodule.o  Modules/grpmodule.o  '
+            'Modules/_struct.o  Modules/_randommodule.o  '
+            'Modules/_elementtree.o  Modules/_pickle.o  '
+            'Modules/_datetimemodule.o  Modules/_bisectmodule.o  '
+            'Modules/_heapqmodule.o  Modules/unicodedata.o  '
+            'Modules/fcntlmodule.o  Modules/spwdmodule.o  Modules/grpmodule.o  '
             'Modules/selectmodule.o  Modules/socketmodule.o  '
             'Modules/_posixsubprocess.o  Modules/md5module.o  '
             'Modules/sha1module.o  Modules/sha256module.o  '
@@ -531,10 +541,10 @@ build_time_vars = {'ABIFLAGS': 'm',
             'Modules/_weakref.o  Modules/_functoolsmodule.o  '
             'Modules/_operator.o  Modules/_collectionsmodule.o  '
             'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
-            'Modules/_stat.o  Modules/_localemodule.o  Modules/_iomodule.o '
-            'Modules/iobase.o Modules/fileio.o Modules/bytesio.o '
-            'Modules/bufferedio.o Modules/textio.o Modules/stringio.o  '
-            'Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
+            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
+            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
             'Modules/_tracemalloc.o Modules/hashtable.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
@@ -545,6 +555,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETGEN': '\\',
  'OPCODETARGETGEN_FILES': '\\',
  'OPCODETARGETS_H': '\\',
+ 'OPCODE_H': '../Include/opcode.h',
+ 'OPCODE_H_DIR': '../Include',
+ 'OPCODE_H_GEN': 'python3.5  ../Tools/scripts/generate_opcode_h.py '
+                 '../Lib/opcode.py ../Include/opcode.h',
+ 'OPCODE_H_SCRIPT': '../Tools/scripts/generate_opcode_h.py',
  'OPT': '-DNDEBUG -g -fwrapv -O2 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -559,11 +574,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
+ 'PGO_PROF_USE_FLAG': '',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-arm-linux-gnueabihf',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '../Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
+                 'test_multiprocessing_fork test_multiprocessing_forkserver '
+                 'test_multiprocessing_main_handling '
+                 'test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -578,18 +598,19 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O2 -Wall '
-              '-Wstrict-prototypes -g -fstack-protector '
-              '--param=ssp-buffer-size=4 -Wformat -Werror=format-security  '
-              '',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
+              '-Wstrict-prototypes -g -fstack-protector-strong -Wformat '
+              '-Werror=format-security  -g -flto -fuse-linker-plugin '
+              '-ffat-lto-objects',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O2 -Wall '
-                   '-Wstrict-prototypes -g -fstack-protector '
-                   '--param=ssp-buffer-size=4 -Wformat '
-                   '-Werror=format-security   '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 '
+                   '-Wall -Wstrict-prototypes -g -fstack-protector-strong '
+                   '-Wformat -Werror=format-security  -g -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects '
                    '-Werror=declaration-after-statement -I. -IInclude '
-                   '-I../Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-I. -IInclude -I../Include -D_FORTIFY_SOURCE=2',
+                   '-I../Include -Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
+                   '-DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -IInclude -I../Include -Wdate-time -D_FORTIFY_SOURCE=2',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-Bsymbolic-functions -Wl,-z,relro',
@@ -601,7 +622,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.5-AsTze5/python3.5-3.5.2/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -628,8 +649,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-34m',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SOABI': 'cpython-35m-arm-linux-gnueabihf',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -643,10 +664,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.5-AsTze5/python3.5-3.5.2/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.5-AsTze5/python3.5-3.5.2/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -658,7 +679,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '3.4',
+ 'VERSION': '3.5',
  'VPATH': '..',
  'WANT_SIGFPE_HANDLER': 1,
  'WINDOW_HAS_FLAGS': 1,
@@ -672,8 +693,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared',
- 'abs_srcdir': '/build/python3.4-GJ5Z3E/python3.4-3.4.3/build-shared/..',
+ 'abs_builddir': '/build/python3.5-AsTze5/python3.5-3.5.2/build-shared',
+ 'abs_srcdir': '/build/python3.5-AsTze5/python3.5-3.5.2/build-shared/..',
+ 'cross_compiling': 'no',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
